==> catalystcentersdk-2.3.7.9.3-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_6_1/jsd_bf40cea4982c54278a52ac2e7b0c458a.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center DeployTemplateV2 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""



import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorBf40Cea4982C54278A52Ac2E7B0C458A(object):
    """DeployTemplateV2 request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorBf40Cea4982C54278A52Ac2E7B0C458A, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "forcePushTemplate": {
                "type": "boolean"
                },
                "isComposite": {
                "type": "boolean"
                },
                "mainTemplateId": {
                "type": "string"
                },
                "memberTemplateDeploymentInfo": {
                "items": {
                "type": "object"
                },
                "type": "array"
                },
                "targetInfo": {
                "items": {
                "properties": {
                "hostName": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "params": {
                "type": "object"
                },
                "resourceParams": {
                "items": {
                "type": "object"
                },
                "type": "array"
                },
                "type": {
                "enum": [
                "MANAGED_DEVICE_IP",
                "MANAGED_DEVICE_UUID",
                "PRE_PROVISIONED_SERIAL",
                "PRE_PROVISIONED_MAC",
                "DEFAULT",
                "MANAGED_DEVICE_HOSTNAME"
                ],
                "type": "string"
                },
                "versionedTemplateId": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "templateId": {
                "type": "string"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> catalystcentersdk-3.1.3.0.0-py3-none-any.whl: catalystcentersdk/models/validators/v2_3_7_9/jsd_bf40cea4982c54278a52ac2e7b0c458a.py <==
# -*- coding: utf-8 -*-
"""Cisco Catalyst Center DeployTemplateV2 data model.

Copyright (c) 2024 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


import json
from builtins import *

import fastjsonschema

from catalystcentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorBf40Cea4982C54278A52Ac2E7B0C458A(object):
    """DeployTemplateV2 request schema definition."""

    def __init__(self):
        super(JSONSchemaValidatorBf40Cea4982C54278A52Ac2E7B0C458A, self).__init__()
        self._validator = fastjsonschema.compile(
            json.loads(
                """{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "forcePushTemplate": {
                "type": "boolean"
                },
                "isComposite": {
                "type": "boolean"
                },
                "mainTemplateId": {
                "type": "string"
                },
                "memberTemplateDeploymentInfo": {
                "items": {
                "type": "object"
                },
                "type": "array"
                },
                "targetInfo": {
                "items": {
                "properties": {
                "hostName": {
                "type": "string"
                },
                "id": {
                "type": "string"
                },
                "params": {
                "type": "object"
                },
                "resourceParams": {
                "items": {
                "type": "object"
                },
                "type": "array"
                },
                "type": {
                "enum": [
                "MANAGED_DEVICE_IP",
                "MANAGED_DEVICE_UUID",
                "PRE_PROVISIONED_SERIAL",
                "PRE_PROVISIONED_MAC",
                "DEFAULT",
                "MANAGED_DEVICE_HOSTNAME"
                ],
                "type": "string"
                },
                "versionedTemplateId": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                },
                "templateId": {
                "type": "string"
                }
                },
                "type": "object"
                }""".replace(
                    "\n" + " " * 16, ""
                )
            )
        )

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                "{} is invalid. Reason: {}".format(request, e.message)
            )
